@@ -1,8 +1,8 @@
 from pyspark.sql import types as T
-from jobsworthy.repo import hive_repo
+from jobsworthy import repo
 
 
-class PerformanceMetric(hive_repo.HiveRepo):
+class PerformanceMetric(repo.HiveRepo):
     table_name = None
 
     def emit_metrics(self, perf_data):
